@@ -1,4 +1,4 @@
-use anyhow::{Context, Result};
+use anyhow::{anyhow, bail, Context, Result};
 use std::collections::BTreeMap;
 use swayipc::{Connection, EventStream, EventType, Node, NodeType};
 
@@ -14,7 +14,8 @@ trait NodeExt {
 
 impl NodeExt for Node {
     fn is_workspace(&self) -> bool {
-        self.node_type == NodeType::Workspace
+        // `__i3_scratch` is a special workspace that connot be renamed, so we just skip it
+        self.name.as_deref() != Some("__i3_scratch") && self.node_type == NodeType::Workspace
     }
     fn is_window(&self) -> bool {
         matches!(self.node_type, NodeType::Con | NodeType::FloatingCon)
@@ -50,8 +51,7 @@ impl NodeExt for Node {
         for node in &self.nodes {
             if node.is_workspace() {
                 res.insert(
-                    node.name()
-                        .ok_or_else(|| anyhow!("Expected some node name"))?,
+                    node.name().context("Expected some node name")?,
                     node.windows_in_node(),
                 );
             } else {
@@ -133,9 +133,13 @@ impl WindowManager {
     }
 
     pub fn rename_workspace(&mut self, old: &str, new: &str) -> Result<()> {
-        self.connection
+        for result in self
+            .connection
             .run_command(&format!("rename workspace \"{old}\" to \"{new}\"",))
-            .context("Failed to rename the workspace")?;
+            .context("Failed to rename the workspace")?
+        {
+            result.context("Failed to rename the workspace")?;
+        }
         Ok(())
     }
 
